============
Installation
============

This is an OpenStack Client plugin for the vpn-server (Tunnel) project.

Install the vpn-server (Tunnel) plugin::

    $ pip install python-tunnelclient

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv python-tunnelclient
    $ pip install python-tunnelclient

.. note:: If python-openstackclient is not already installed it will be
          installed as part of the requirements for the Tunnel client plugin.
